#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-J9QF3n0MJ92K359rVxm429
key:                  haskell-language-server-2.3.0.0-J9QF3n0MJ92K359rVxm429
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ff6d7e1246a0b4db77fcff23c1932004
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-J9QF3n0MJ92K359rVxm429
depends:
    aeson-pretty-0.8.10-F4F6KctyCy3LGoieEXRGS6
    async-2.2.6-HlTb8qs1wHD7UNlnrqlxTX base-4.18.2.1
    base16-bytestring-1.0.2.0-CyRVdTn3Mp2LljOO1UuYPC
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-1n6qpQSH7rL4d8Ie37CZu
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-7J4flVDuVp79ZQl3ULvjo5 filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-HbBecx74htg70XGZBoVLBG
    githash-0.1.6.3-8hhXA9sCzDH2m7bfBB6CBf
    hie-bios-0.12.0-8LqvEEYs8LS1N5E8DqmCHm
    hiedb-0.4.3.0-BPSgi52jb5DFIEstvfuIK5
    hls-alternate-number-format-plugin-2.3.0.0-BwggNHrO7t89dLaoi0FUrW
    hls-cabal-fmt-plugin-2.3.0.0-76prmsIwb8U41cF9IykxAv
    hls-cabal-plugin-2.3.0.0-AMqksGu1PpN7Y5qe1CBdeZ
    hls-call-hierarchy-plugin-2.3.0.0-9171pkVOI9EHsbr1yifSp
    hls-change-type-signature-plugin-2.3.0.0-GKxfwEBJ47Rt75H3nZ1oK
    hls-class-plugin-2.3.0.0-3COxeXM8qwZsyDsBdPTVs
    hls-code-range-plugin-2.3.0.0-4470kPW43fI7IitOLt7L1e
    hls-eval-plugin-2.3.0.0-9hmOYChJ2wj7V6No0N7xzK
    hls-explicit-fixity-plugin-2.3.0.0-1nwEobyEfqiGht0V0d1QvK
    hls-explicit-imports-plugin-2.3.0.0-54Q9QPZ8cWPAuBK625d30i
    hls-explicit-record-fields-plugin-2.3.0.0-FOuhGGVYRC61uvhMTorBqe
    hls-fourmolu-plugin-2.3.0.0-4FyHalXAh4tHTYJTGuLYia
    hls-gadt-plugin-2.3.0.0-9snmfOOyVky8mYdftgggsk
    hls-graph-2.3.0.0-C0ii0lxGNjwCMvRrwCM0Qd
    hls-hlint-plugin-2.3.0.0-JZIlUi80jIuHuHR5Uk1WLX
    hls-module-name-plugin-2.3.0.0-2VizicoB2sPFSK9bL4XmIm
    hls-ormolu-plugin-2.3.0.0-AJkYspE9DBF4o7LIEvLzSv
    hls-overloaded-record-dot-plugin-2.3.0.0-K28xNM5sVszBjYyfHXKto4
    hls-plugin-api-2.3.0.0-HYdBIsoiAM91QY4A9avICV
    hls-pragmas-plugin-2.3.0.0-K8u6vWZ268JGcb1Q0QbVfA
    hls-qualify-imported-names-plugin-2.3.0.0-Cqn4PeAZX9Y3NXDzT4glKx
    hls-refactor-plugin-2.3.0.0-FzjDgVtsGAS9OQvHzfCXBR
    hls-rename-plugin-2.3.0.0-4F8APwUKDNKKSYL6mTcFeb
    hls-retrie-plugin-2.3.0.0-619kkQsGE7z6XOksRdfY1o
    hls-splice-plugin-2.3.0.0-7CDRZJYoL6VDkItn3CxFeh
    hls-stylish-haskell-plugin-2.3.0.0-ElzADwdZajf6tdVKUEyfZd
    lsp-2.2.0.0-LeT2ktaJdH62xlttOS1KCX
    optparse-applicative-0.18.1.0-CWeKmfCITC3AeEtxQrg6nv
    optparse-simple-0.1.1.4-7RbuAYyQHiLK3priYU1rO2
    prettyprinter-1.7.1-2nVenIIUlIN10A4pxpSujW process-1.6.19.0
    safe-exceptions-0.1.7.4-3TnkhxhKDMDEKYWErsKJ7P
    sqlite-simple-0.4.19.0-IDXGUcIWXzF45jPSRPuUQn text-2.0.2
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

